# Set rev to svn revision when using pre-release tarball, otherwise set to 0.
%define rev	0
%define rel	4
%if %{rev}
%define release	%mkrel -c %{rev} %{rel}
%else
%define release	%mkrel %{rel}
%endif
%define oname	Ardour3

Name:		ardour3
Version:	3.4
Release:	%{release}
Summary:	Professional multi-track audio recording application
Group:		Sound/Editors and Converters
License:	GPLv2+
URL:		http://ardour.org/

# Pre-release tarballs may be created in SOURCES with:
# ./mk_svn_tar ardour3 http://subversion.ardour.org/svn/ardour2/branches/3.0 tar.bz2
%if %{rev}
Source0:	%{name}-%{rev}.tar.bz2
%else
# NB to receive a free (as beer) source tarball you need to give your e-mail address here:
# "http://community.ardour.org/download_process_selection_and_amount" to get a download link
Source0:	%{oname}-%{version}.tar.bz2
%endif
Source1:	%{name}.desktop
Source2:	mk_svn_tar

BuildRequires:	boost-devel
BuildRequires:	dmalloc
BuildRequires:	doxygen
BuildRequires:	gettext
BuildRequires:	graphviz
BuildRequires:	gtk2-devel >= 2.12.1
BuildRequires:	gtkmm2.4-devel >= 2.8
BuildRequires:	jackit-devel
BuildRequires:	shared-mime-info
BuildRequires:	xdg-utils
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(aubio) >= 0.3.2
BuildRequires:	pkgconfig(cppunit) >= 1.12.0
BuildRequires:	pkgconfig(cwiid)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(flac) >= 1.2.1
BuildRequires:	pkgconfig(glib-2.0) >= 2.2
BuildRequires:	pkgconfig(libart-2.0)
BuildRequires:	pkgconfig(libcurl) >= 7.0.0
BuildRequires:	pkgconfig(libgnomecanvas-2.0) >= 2.30
BuildRequires:	pkgconfig(libgnomecanvasmm-2.6) >= 2.16
BuildRequires:	pkgconfig(liblo) >= 0.24
BuildRequires:	pkgconfig(libusb)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	pkgconfig(lilv-0) >= 0.14
BuildRequires:	pkgconfig(lrdf) >= 0.4.0
BuildRequires:	pkgconfig(ltc) >= 1.1.0
BuildRequires:	pkgconfig(lv2) >= 1.0.15
BuildRequires:	pkgconfig(ogg) >= 1.1.2
BuildRequires:	pkgconfig(raptor2)
BuildRequires:	pkgconfig(redland)
BuildRequires:	pkgconfig(rubberband)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(serd-0) >= 0.14.0
BuildRequires:	pkgconfig(sndfile) >= 1.0.18
BuildRequires:	pkgconfig(sord-0) >= 0.8.0
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(sratom-0) >= 0.4.0
BuildRequires:	pkgconfig(suil-0) >= 0.6.0
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(vamp-sdk)
BuildRequires:	desktop-file-utils

Requires:	jackit
Requires:	gtk-engines2

Provides:	ardour = 1:%{version}-%{release}
Obsoletes:	ardour < 1:2.9

%description
Ardour3 is a digital audio workstation. You can use it to record, edit and mix
multi-track audio. You can produce your own CDs, mix video sound tracks, or
just experiment with new ideas about music and sound.

Ardour3 capabilities include: multi channel recording, non-destructive editing
with unlimited undo/redo, full automation support, a powerful mixer, unlimited
tracks/busses/plugins, time-code synchronization, and hardware control from
surfaces like the Mackie Control Universal.

You must have jackd running and an ALSA sound driver to use Ardour3. If you are
new to jackd, try qjackctl.

See the online user manual at http://en.flossmanuals.net/ardour/index/

%prep
%if %{rev}
%setup -q -n %{name}
%else
%setup -q -n %{oname}-%{version}
%endif

%build
./waf configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --configdir=%{_sysconfdir} \
    --program-name=Ardour3 \
    --nls \
    --docs

./waf build \
    --nls \
    --docs

./waf i18n_mo

%install
./waf install --destdir=%{buildroot}

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{SOURCE1}

# Symlink icons and mimetypes into the right folders
install -d -m 0755 %{buildroot}%{_iconsdir}

for i in 16 22 32 48; do
install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/mimetypes
ln -s %{_datadir}/%{name}/icons/application-x-ardour_${i}px.png \
%{buildroot}%{_iconsdir}/hicolor/${i}x${i}/mimetypes/application-x-ardour3.png
ln -s %{_datadir}/%{name}/icons/ardour_icon_${i}px.png \
%{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/ardour3.png
done

%files
%doc README
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}_ui_default.conf
%config(noreplace) %{_sysconfdir}/%{name}/%{name}_ui_light.rc
%config(noreplace) %{_sysconfdir}/%{name}/%{name}_ui_dark.rc
%config(noreplace) %{_sysconfdir}/%{name}/ardour.menus
%config(noreplace) %{_sysconfdir}/%{name}/ardour_system.rc
%config(noreplace) %{_sysconfdir}/%{name}/step_editing.bindings
%config(noreplace) %{_sysconfdir}/%{name}/mnemonic-us.bindings
%config(noreplace) %{_sysconfdir}/%{name}/mixer.bindings
%dir %{_sysconfdir}/%{name}/export
%config(noreplace) %{_sysconfdir}/%{name}/export/CD.format
%{_iconsdir}/hicolor/*
%{_datadir}/locale/*/*/*.mo


%changelog
* Wed Nov 27 2013 pterjan <pterjan> 3.4-4.mga4
+ Revision: 553637
- Add Epoch to Provides/Obsoletes

* Sat Oct 19 2013 umeabot <umeabot> 3.4-3.mga4
+ Revision: 536056
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 barjac <barjac> 3.4-2.mga4
+ Revision: 502308
- obsolete ardour

* Sat Sep 21 2013 barjac <barjac> 3.4-1.mga4
+ Revision: 483094
- new version 3.4

* Tue Jul 09 2013 fwang <fwang> 3.2-2.mga4
+ Revision: 451703
- rebuild for new boost

* Sun Jun 30 2013 barjac <barjac> 3.2-1.mga4
+ Revision: 448419
- new version 3.2

* Thu May 23 2013 barjac <barjac> 3.1-1.mga4
+ Revision: 425428
- new version

* Fri Mar 29 2013 barjac <barjac> 3.0-2.mga3
+ Revision: 406433
- changed group to match ardour
- better handling of icons

* Tue Mar 26 2013 barjac <barjac> 3.0-1.mga3
+ Revision: 405307
- update from svn snapshot to official release
- simplify/tidy spec
- add BR desktop-file-utils

* Fri Jan 11 2013 umeabot <umeabot> 3.0-0.13700.2.mga3
+ Revision: 346019
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 barjac <barjac> 3.0-0.13700.1.mga3
+ Revision: 334045
- new snapshot

* Mon Dec 03 2012 barjac <barjac> 3.0-0.13546.2.mga3
+ Revision: 325979
- locales added to build
- conditional release handling for svn snapshots

* Fri Nov 30 2012 barjac <barjac> 3.0-0.13546.1.mga3
+ Revision: 323561
- Corrected error in .desktop file
- removed temp clean section
- removed no-push warning :)
- corrected one BR
- corrected link url in description
- removed a comment
- Added more versioned BRs
- use mkrel -c
- use _sysconfdir macro in configure
 - add --program-name to show Ardour3 in main window header
- fixed config path thanks to Philippe Didier
- added back some minimum BR versions
- added ltc support
- tidy files with wildcards
- added BR ltc
- removed some BRs already indirectly required
- new package ardour3

